@@ -18,14 +18,15 @@ import random
 import py_compile
 from pathlib import Path
 from clouderizer.cldz_aws_lambda import lambda_deploy, lambda_delete, aws_region_set
-from clouderizer.utils import check_aws_cli_exists, check_sam_cli_exists, prepend_line
+from clouderizer.utils import check_aws_cli_exists, check_sam_cli_exists
 from yaml import load, dump
-# from clouderizer.utils import prepend_line
+# from clouderizer_beta.utils import prepend_line
 try:
     from yaml import CLoader as Loader, CDumper as Dumper
 except ImportError:
     from yaml import Loader, Dumper
 
+# BASE_URL="https://showcase.clouderizer.com"
 BASE_URL="https://showcase.clouderizer.com"
 SYNC_URL="https://serverless.clouderizer.com/function/"
 
@@ -478,7 +479,7 @@ def create_serving_project(filename,companyid,auth_token,projectName=None,inputA
 		return create_serving_project(filename,companyid,auth_token,retry)
 
 
-def create_serving_model(file_name,s3Path,servingproject,servingprojectid,pipPackages,auth_token,training,model_type,subtype,image_type,preprocess=None,postprocess=None,predict=None,inputAttrs=[],outputAttrs=[],retry=0):
+def create_serving_model(file_name,s3Path,servingproject,servingprojectid,pipPackages,auth_token,training,model_type,subtype,image_type,preprocess=None,postprocess=None,predict=None,inputAttrs=[],outputAttrs=[],retry=0,is_lambda_deploy="false"):
 	# print("Inside")
 	company=servingproject["company"]
 	auth_headers={"Authorization": "Bearer "+auth_token}
@@ -530,7 +531,8 @@ def create_serving_model(file_name,s3Path,servingproject,servingprojectid,pipPac
 		"predictCodePath": predictS3Path,
 		"imagetype" : image_type,
 		"inputAttr" : inputAttrs,
-		"outputAttr": outputAttrs
+		"outputAttr": outputAttrs,
+		"lambda": is_lambda_deploy
 	}
 
 	model_resp=requests.post(BASE_URL+'/api/servingmodel',data=model,headers=auth_headers)
@@ -954,7 +956,7 @@ class Clouderizer(object):
 
 		published_serving_projects=requests.post(BASE_URL+'/api/servingproject/getprojects',data={"company":creds["cid"]})
 
-		# print(published_serving_projects.text)
+		print(published_serving_projects.text)
 		published_serving_projects=parse_json(published_serving_projects.text)
 		clear_local_project_list()
 		# except Exception as e:
@@ -1527,8 +1529,8 @@ class Clouderizer(object):
 		subtype="pythonscore"
 
 
-		inputAttrs={"inputList":[], "rawinputList":[]} 
-		outputAttrs={"outputlist": [],"finaloutput":[]}
+		inputAttrs=[{"inputList":[], "rawinputList":[]}] 
+		outputAttrs=[{"outputList": [],"finaloutput":[]}]
 		if schema:
 			inputAttrs, outputAttrs = parse_yaml(schema)
 
@@ -1697,7 +1699,7 @@ class Clouderizer(object):
 				checkPathExists(predict_path)
 				checkFileSyntax(predict_path)
 
-				prepend_line(predict_path,"modelPath='/home/app/function/asset/model.file'")
+				# prepend_line(predict_path,"modelPath='/home/app/function/asset/model.file'")
 				# if not os.path.exists(predict_path):
 				# 	print("Preprocess path does not exist " + predict_path)
 				# 	return	
@@ -1961,7 +1963,7 @@ class Clouderizer(object):
 				uploadmodel_resp=upload_to_showcase(s3Path,notebook_path,servingproject["company"],auth_token)
 				if uploadmodel_resp=="Success":
 					try:
-						servingmodel=create_serving_model(file_name,s3Path,servingproject,servingproject["id"],pipPackages,auth_token,"true","regular",subtype,"standard")
+						servingmodel=create_serving_model(file_name,s3Path,servingproject,servingproject["id"],pipPackages,auth_token,"true","regular",subtype,"standard",is_lambda_deploy="true")
 					except Exception as e:
 						print(e)
 						print("Some exception occurred while preparing your notebook, please try again!")
@@ -1991,8 +1993,8 @@ class Clouderizer(object):
 			preprocess_path=preprocess
 			postprocess_path=postprocess
 
-			inputAttrs={"inputList":[], "rawinputList":[]} 
-			outputAttrs={"outputlist": [],"finaloutput":[]}
+			inputAttrs=[{"inputList":[], "rawinputList":[]}] 
+			outputAttrs=[{"outputlist": [],"finaloutput":[]}]
 			if schema:
 				inputAttrs, outputAttrs = parse_yaml(schema)
 
@@ -2036,7 +2038,8 @@ class Clouderizer(object):
 				checkPathExists(predict_path)
 				checkFileSyntax(predict_path)
 
-				prepend_line(predict_path,"modelPath='/home/app/function/model.file'")
+				# if "modelPath=" not in open(predict_path,'r').read():
+				# 	prepend_line(predict_path,"modelPath='/home/app/function/model.file'")
 				# if not os.path.exists(predict_path):
 				# 	print("Preprocess path does not exist " + predict_path)
 				# 	return	
@@ -2186,4 +2189,35 @@ def main():
 
 
 if __name__ == '__main__':
+	# if len(sys.argv)==1:
+	# 	print("NAME")
+	# 	print("    cldz")
+	# 	print(" ")
+	# 	print("Options in {} are optional")
+	# 	print(" ")
+	# 	print("SYNOPSIS")
+	# 	print("    cldz COMMAND")
+	# 	print(" ")
+	# 	print("COMMANDS")
+	# 	print("    COMMAND is one of the following:")
+	# 	print("    ")
+	# 	print("        delete $PROJECT_NAME : delete an existing project")
+	# 	print("    ")
+	# 	print("        deploy $NOTEBOOK_PATH {REQUIREMENTS_PATH} : create a new project, upload notebook/model and deploy")
+	# 	print("    ")
+	# 	print("        describe $PROJECT_NAME : get details of the existing project")
+	# 	print("    ")
+	# 	print("        loggedin : to check whether logged in with cldz or not")
+	# 	print("    ")
+	# 	print("        login")
+	# 	print("    ")
+	# 	print("        logout")
+	# 	print("    ")
+	# 	print("        ls : list all the projects")
+	# 	print("    ")
+	# 	print("        start $PROJECT_NAME : start an existing project")
+	# 	print("    ")
+	# 	print("        stop $PROJECT_NAME : stop an existing project")
+	# 	print("    ")
+	# else:
 	main()
